Crate tui_widgets
source ·Expand description
A collection of useful widgets for building terminal user interfaces using Ratatui.
This is a crate that combines multiple previously standalone crates into one in order simplify maintenance and to make it easier to use the widgets together.
Includes the following widgets, which are also available as standalone crates:
features
default— By default, all the widgets are enabled.big-text(enabled by default) — Enables thebig_textwidgetpopup(enabled by default) — Enables thepopupwidgetprompts(enabled by default) — Enables thepromptswidgetscrollview(enabled by default) — Enables thescrollviewwidget
Modules
- tui-big-text is a rust crate that renders large pixel text as a Ratatui widget using the glyphs from the font8x8 crate.
- A popup widget for Ratatui
- Tui-scrollview