Enum tui_widgets::big_text::PixelSize
source · pub enum PixelSize {
Full,
HalfHeight,
HalfWidth,
Quadrant,
ThirdHeight,
Sextant,
}Variants
Full
A pixel from the 8x8 font is represented by a full character cell in the terminal.
HalfHeight
A pixel from the 8x8 font is represented by a half (upper/lower) character cell in the terminal.
HalfWidth
A pixel from the 8x8 font is represented by a half (left/right) character cell in the terminal.
Quadrant
A pixel from the 8x8 font is represented by a quadrant of a character cell in the terminal.
ThirdHeight
A pixel from the 8x8 font is represented by a third (top/middle/bottom) of a character
cell in the terminal.
Note: depending on how the used terminal renders characters, the generated text with
this PixelSize might look very strange.
Sextant
A pixel from the 8x8 font is represented by a sextant of a character cell in the
terminal.
Note: depending on how the used terminal renders characters, the generated text with
this PixelSize might look very strange.