pub struct SelectOptionList<'a> { /* private fields */ }Expand description
An ordered list of selectable values for a SelectPrompt.
Arrays and vectors of values that convert into SelectOption can be converted into a
SelectOptionList, which keeps simple string lists concise:
use std::borrow::Cow;
use tui_prompts::{SelectOptionList, SelectPrompt};
let options: SelectOptionList = ["Rust", "Zig", "Go"].into();
let prompt = SelectPrompt::new(Cow::Borrowed("Language"), options);Implementations
Sourceimpl<'a> SelectOptionList<'a>
impl<'a> SelectOptionList<'a>
Sourcepub const fn new(options: Vec<SelectOption<'a>>) -> SelectOptionList<'a>
pub const fn new(options: Vec<SelectOption<'a>>) -> SelectOptionList<'a>
Creates an option list from explicit option values.
Sourcepub fn iter(&self) -> impl Iterator<Item = &SelectOption<'a>>
pub fn iter(&self) -> impl Iterator<Item = &SelectOption<'a>>
Returns an iterator over the options.